|title|_
=========

.. |title| replace:: bobleesj.utils
.. _title: https://bobleesj.github.io/bobleesj.utils'

|PyPi| |Forge| |PythonVersion| |PR|

|CI| |Codecov| |Black| |Tracking|

.. |Black| image:: https://img.shields.io/badge/code_style-black-black
        :target: https://github.com/psf/black

.. |CI| image:: https://github.com/bobleesj/bobleesj.utils/actions/workflows/matrix-and-codecov-on-merge-to-main.yml/badge.svg
        :target: https://github.com/bobleesj/bobleesj.utils/actions/workflows/matrix-and-codecov-on-merge-to-main.yml

.. |Codecov| image:: https://codecov.io/gh/bobleesj/bobleesj.utils/branch/main/graph/badge.svg
        :target: https://codecov.io/gh/bobleesj/bobleesj.utils

.. |Forge| image:: https://img.shields.io/conda/vn/conda-forge/bobleesj.utils
        :target: https://anaconda.org/conda-forge/bobleesj.utils

.. |PR| image:: https://img.shields.io/badge/PR-Welcome-29ab47ff

.. |PyPi| image:: https://img.shields.io/pypi/v/bobleesj.utils
        :target: https://pypi.org/project/bobleesj.utils/

.. |PythonVersion| image:: https://img.shields.io/pypi/pyversions/bobleesj.utils
        :target: https://pypi.org/project/bobleesj.utils/

.. |Tracking| image:: https://img.shields.io/badge/issue_tracking-github-blue
        :target: https://github.com/bobleesj/'/issues


Motivation
----------

``bobleesj.utils`` is a Python package that provides a collection of utility functions and classes to simplify common tasks in materials informatics. ``bobleesj.utils`` is used across scientific software projects created and maintained by @bobleesj.

Please visit https://bobleesj.github.io/bobleesj.utils to see the documentation and examples of how to use this package.

Acknowledgements
----------------

This GitHub repository is built and maintained with the help of `scikit-package <https://scikit-package.github.io/scikit-package/>`_.
